===============================
Python AutoTask Web Services 
===============================


.. image:: https://img.shields.io/pypi/v/atws.svg
        :target: https://pypi.python.org/pypi/atws

.. image:: https://img.shields.io/travis/MattParr/python-atws.svg
        :target: https://travis-ci.org/MattParr/python-atws

.. image:: https://readthedocs.org/projects/atws/badge/?version=latest
        :target: https://atws.readthedocs.io/
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/mattparr/cookiecutter-django/shield.svg
     :target: https://pyup.io/repos/github/mattparr/python-atws/
     :alt: Updates


atws is a wrapper for the AutoTask SOAP webservices API


* Free software: MIT license
* Documentation: https://atws.readthedocs.io.


Features
--------

* Py2 and Py3 support
* Easy, programmatic query writing (no XML required)
* Query result generator retrieves all entities, not just 500
* Zone discovery (you only need a username and password)
* Picklist python module creator (IDE autofill your picklist IDs)

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

